Gestione efficace dei casi di assistenza IBM Cloud

Imparate a gestire i casi di assistenza di IBM Cloud, tra cui il monitoraggio dei progressi, l'aggiornamento dei casi e la gestione delle liste di controllo per una risoluzione efficace dei problemi.

Per visualizzare e gestire le tue richieste di assistenza, vai alla pagina "Gestisci richieste ". Se utilizzi l'infrastruttura classica e non vedi l'elenco dei casi precedenti, fai clic su " Visualizza i casi relativi all'infrastruttura classica ". È inoltre possibile ottenere una rapida visualizzazione dei 5 casi aperti aggiornati più di recente digitando case status nell'assistente AI IBM Cloud.

I casi di assistenza di IBM possono essere visualizzati anche nella pagina Gestisci casi, ma possono essere gestiti solo nel portale di assistenza IBM. L'accesso alla visualizzazione di questi casi è controllato dal portale di assistenza IBM. Per ulteriori informazioni sull'accesso, vedere Gestione dell'accesso all'account di supporto.

Visualizzazione dei casi di assistenza tramite l'API

È possibile visualizzare programmaticamente un caso di assistenza utilizzando l'API, come mostrato nella seguente richiesta di esempio. Per ulteriori informazioni, consultare l'API Gestione casi.

Per visualizzare un caso, vedere i seguenti esempi:

curl -X GET 'https://support-center.cloud.ibm.com/case-management/v1/cases/{case_number}?fields=number,updated_at,resources' -H 'Authorization: TOKEN' \
GetCaseOptions getCaseOptions = new GetCaseOptions.Builder()
  .caseNumber(caseNumber)
  .addFields(GetCaseOptions.Fields.DESCRIPTION)
  .addFields(GetCaseOptions.Fields.STATUS)
  .addFields(GetCaseOptions.Fields.SEVERITY)
  .addFields(GetCaseOptions.Fields.CREATED_BY)
  .build();
Response<Case> response = service.getCase(getCaseOptions).execute();
Case xCase = response.getResult();
System.out.println(xCase);
const fieldsToReturn = [
  CaseManagementV1.GetCaseConstants.Fields.DESCRIPTION,
  CaseManagementV1.GetCaseConstants.Fields.STATUS,
  CaseManagementV1.GetCaseConstants.Fields.SEVERITY,
  CaseManagementV1.GetCaseConstants.Fields.CREATED_BY,
];
const params = {
  caseNumber: caseNumber,
  fields: fieldsToReturn,
};
caseManagementService.getCase(params)
  .then(res => {
    console.log(JSON.stringify(res.result, null, 2));
  })
  .catch(err => {
    console.warn(err)
  });
fields_to_return = [
  GetCaseEnums.Fields.DESCRIPTION,
  GetCaseEnums.Fields.STATUS,
  GetCaseEnums.Fields.SEVERITY,
  GetCaseEnums.Fields.CREATED_BY,
]
case = case_management_service.get_case(
  case_number=case_number,
  fields=fields_to_return
).get_result()
print(json.dumps(case, indent=2))
getCaseOptions := caseManagementService.NewGetCaseOptions(
  caseNumber,
)
getCaseOptions.SetFields([]string{
  casemanagementv1.GetCaseOptionsFieldsDescriptionConst,
  casemanagementv1.GetCaseOptionsFieldsStatusConst,
  casemanagementv1.GetCaseOptionsFieldsSeverityConst,
  casemanagementv1.GetCaseOptionsFieldsCreatedByConst,
})
caseVar, response, err := caseManagementService.GetCase(getCaseOptions)
if err != nil {
  panic(err)
}
b, _ := json.MarshalIndent(caseVar, "", "  ")
fmt.Println(string(b))

Aggiornamento dei casi di assistenza tramite l'API

La seguente richiesta di esempio mostra come aggiornare programmaticamente un caso di assistenza. Per ulteriori informazioni, consultare l'API Gestione casi.

curl -X PUT '/case-management/v1/cases/{case_number}/status' -H 'Authorization: TOKEN' -d '{
  "action": "resolve",
  "comment": "The issue is resolved. Thank you!",
  "resolution_code": 1
}'
ResolvePayload statusPayloadModel = new ResolvePayload.Builder()
  .action("resolve")
  .comment("The problem has been resolved.")
  .resolutionCode(1)
  .build();
UpdateCaseStatusOptions updateCaseStatusOptions = new UpdateCaseStatusOptions.Builder()
  .caseNumber(caseNumber)
  .statusPayload(statusPayloadModel)
  .build();
Response<Case> response = service.updateCaseStatus(updateCaseStatusOptions).execute();
Case xCase = response.getResult();
System.out.println(xCase);
const statusPayloadModel = {
  action: 'resolve',
  comment: 'The problem has been resolved.',
  resolution_code: 1,
};
const params = {
  caseNumber: caseNumber,
  statusPayload: statusPayloadModel,
};
caseManagementService.updateCaseStatus(params)
  .then(res => {
    console.log(JSON.stringify(res.result, null, 2));
  })
  .catch(err => {
    console.warn(err)
  });
status_payload_model = {
  'action': 'resolve',
  'comment': 'The problem has been resolved.',
  'resolution_code': 1,
}
case = case_management_service.update_case_status(
  case_number=case_number,
  status_payload=status_payload_model
).get_result()
print(json.dumps(case, indent=2))
statusPayloadModel := &casemanagementv1.ResolvePayload{
  Action:         core.StringPtr("resolve"),
  Comment:        core.StringPtr("The problem has been resolved."),
  ResolutionCode: core.Int64Ptr(int64(1)),
}
updateCaseStatusOptions := caseManagementService.NewUpdateCaseStatusOptions(
  caseNumber,
  statusPayloadModel,
)
caseVar, response, err := caseManagementService.UpdateCaseStatus(updateCaseStatusOptions)
if err != nil {
  panic(err)
}
b, _ := json.MarshalIndent(caseVar, "", "  ")
fmt.Println(string(b))

Aggiunta di commenti ai casi di supporto utilizzando l'API

La seguente richiesta di esempio mostra come aggiungere programmaticamente un commento a un caso di assistenza. Per ulteriori informazioni, consultare l'API Gestione casi.

curl -X PUT '/case-management/v1/cases/{case_number}/comments' -H 'Authorization: TOKEN' -d '{
  "comment": "Test comment api"
}'
AddCommentOptions addCommentOptions = new AddCommentOptions.Builder()
  .caseNumber(caseNumber)
  .comment("This is an example comment.")
  .build();
Response<Comment> response = service.addComment(addCommentOptions).execute();
Comment comment = response.getResult();
System.out.println(comment);
const params = {
  caseNumber: caseNumber,
  comment: 'This is an example comment,',
};
caseManagementService.addComment(params)
  .then(res => {
    console.log(JSON.stringify(res.result, null, 2));
  })
  .catch(err => {
    console.warn(err)
  });
comment = case_management_service.add_comment(
  case_number=case_number,
  comment='This is an example comment.'
).get_result()
print(json.dumps(comment, indent=2))
addCommentOptions := caseManagementService.NewAddCommentOptions(
  caseNumber,
  "This is an example comment.",
)
comment, response, err := caseManagementService.AddComment(addCommentOptions)
if err != nil {
  panic(err)
}
b, _ := json.MarshalIndent(comment, "", "  ")
fmt.Println(string(b))

Aggiornamento dei casi di supporto

Selezionare il numero del caso per aggiornare il caso di assistenza. È possibile aggiungere un commento, allegare o rimuovere file, aggiungere risorse o aggiornare la watchlist. Per aggiornare la tua richiesta di assistenza, segui questi passaggi:

  1. Dalla barra dei menu della console IBM Cloud, fare clic sull'icona Aiuto > Centro assistenza.
  2. Selezionare il caso di assistenza dal riquadro Casi di assistenza recenti.
  3. Aggiungere un commento, quindi fare clic su Invia.
  4. Opzionalmente, è possibile aggiornare i seguenti campi:
    • Aggiungere un utente alla watchlist
    • Allegare o rimuovere i file
    • Aggiungere una risorsa specifica per un caso di assistenza tecnica

Aggiunta di un CRN al commento di un caso

L'aggiunta di dettagli sulle risorse specifiche relative a un caso di assistenza consente un triage, un'indagine e una risoluzione più efficienti. Per visualizzare e copiare un nome di risorsa cloud (CRN) da aggiungere a un caso di assistenza, procedere come segue:

  1. Dalla console IBM Cloud®, fare clic sull'icona del menu di navigazione Menu di navigazione > Elenco risorse per visualizzare l'elenco delle risorse.
  2. Espandere le sezioni per individuare l'istanza di servizio per la quale si desidera recuperare il CRN.
  3. Fare clic sulla riga della tabella. Questa azione apre il pannello laterale della tabella delle risorse, dove è possibile visualizzare il CRN.
  4. Selezionare Copia negli appunti accanto al valore CRN.
  5. Incollare il valore in un commento nel caso di supporto.

Aggiornamento dell'elenco di controllo del caso di supporto

È possibile aggiornare gli utenti del proprio account che possono ricevere le notifiche relative al caso di assistenza aggiungendoli alla watchlist. Gli utenti possono essere aggiunti all'elenco di controllo durante la creazione di casi di assistenza o dopo la creazione del caso di assistenza.

Per impostazione predefinita, gli utenti dell'account non hanno il permesso di creare, aggiornare, cercare o visualizzare i casi. Il titolare dell'account deve concedere l'accesso agli utenti assegnando una politica di accesso IAM ( Identity and Access Management ). Per ulteriori informazioni, vedi Assegnazione dell'accesso utente per lavorare con i casi di supporto.

Per assicurarsi che gli utenti vengano avvisati degli aggiornamenti di un caso di assistenza esistente creato dall'utente, completare i passaggi seguenti per aggiungerli alla watchlist.

  1. Dalla barra dei menu della console IBM Cloud, fare clic sull'icona Aiuto > Centro assistenza.

  2. Selezionare il caso di assistenza dal riquadro Casi di assistenza recenti.

  3. Dalla sezione Watchlist, fare clic sull'icona Impostazioni Icona Impostazioni.

  4. Selezionare gli utenti presenti nell'account da aggiungere alla watchlist.

    Gli utenti aggiunti alla watchlist devono essere membri dell'account in cui è stato creato il caso. Per ulteriori informazioni su come assegnare agli utenti l'accesso al proprio account, vedere Aggiunta di utenti al gruppo di accesso alla gestione dei casi.

Supportare i tipi di stato del caso

Quando è necessaria la vostra risposta a un aggiornamento nel vostro caso di assistenza, lo stato viene visualizzato come Waiting on client. Se non si fornisce una risposta entro sette giorni, lo stato viene aggiornato a Resolved. Il caso viene chiuso se dopo altri sette giorni non c'è ancora una risposta. Per una descrizione di ciascun tipo di stato, vedere la tabella seguente:

Supportare i tipi di stato del caso
Condizione Descrizione
Nuovo Un caso creato non ancora visualizzato da un tecnico dell'assistenza.
In corso Un caso che è in fase di revisione.
In attesa del client Il tecnico dell'assistenza ha inviato una richiesta di informazioni sul caso che richiede la risposta dell'utente.
Risoluzione fornita Il tecnico dell'assistenza ha fornito una risoluzione che l'utente deve eseguire.
Risolto Il caso di assistenza è considerato concluso e pronto per essere chiuso.
Chiuso Il caso è stato chiuso da un tecnico dell'assistenza e non può essere riaperto.

Escalation dei casi di supporto

Con un piano di assistenza a pagamento, è possibile utilizzare il processo di escalation per far emergere problemi critici ed esprimere le proprie preoccupazioni su un caso di assistenza. Quando una richiesta viene inoltrata a un livello superiore, il team di assistenza di IBM Cloud esamina le informazioni contenute nella richiesta e risponde fornendo gli aggiornamenti del caso. Per informazioni sulla gravità del caso, vedere Gravità del caso e tempi di risposta iniziale.

Per eseguire l'escalation di un caso, completa la seguente procedura:

  1. Contattare l'assistenza IBM Cloud tramite chat o telefono.
    • Fare clic su Avvia assistente AI nel Centro assistenza e digitare agent per connettersi con un agente di assistenza
    • Collegarsi telefonicamente utilizzando il numero del Centro di assistenza.
  2. Indica il numero del caso esistente e richiedi che il caso venga sottoposto a un livello superiore.
  3. Fornisci le motivazioni che giustificano l'escalation e spiega l'impatto del problema o della questione in questione sull'attività aziendale.

Piani di assistenza di base: Se si dispone di un piano di assistenza di base, l'accesso all'assistenza avviene solo per casi non tecnici. Se la richiesta di assistenza richiede una risposta più immediata, prendete in considerazione l'aggiornamento a un piano di assistenza Premium o Avanzato, in modo da poter assegnare un livello di gravità a un caso. Per passare a un piano di assistenza superiore, crea una richiesta nel Centro assistenza oppure contatta un rappresentante commerciale di IBM Cloud per ricevere assistenza.

Ricerca di casi di supporto

Dalla pagina Gestione casi, è possibile filtrare in base allo stato del caso e cercare tutti i casi di assistenza utilizzando i parametri di query nella barra di ricerca. I filtri predefiniti sono impostati per visualizzare solo i casi aperti. Per visualizzare i casi risolti o chiusi, aggiorna il filtro dello stato. Tutti i parametri possono essere utilizzati insieme e inseriti in qualsiasi ordine. È inoltre possibile filtrare i casi selezionando Tutti i casi, I miei casi e I casi della lista di controllo.

Per informazioni dettagliate sui parametri di ricerca, consultare la tabella seguente:

Parametri e opzioni della query di ricerca
Parametro Opzione Regola
number numero di caso target Questo parametro non può essere utilizzato con altri parametri. Quando si utilizza il parametro number, tutti gli altri parametri e opzioni vengono ignorati. Il parametro number non riempie automaticamente la ricerca. Per avviare la ricerca è necessario utilizzare l'intero numero del caso.
sort numero
soggetto
gravità
updatedAt
È possibile utilizzare solo una delle opzioni di sort alla volta. È possibile utilizzare il prefisso ~ per invertire l'ordine di ordinamento.
status nuovo
inProgress
waitingOnClient
resolutionProvided
risolto
chiuso
È possibile utilizzare un numero qualsiasi di opzioni. Le opzioni disponibili possono essere inserite come status:new,inProgress o come status:new status:inProgress.
page pagina di destinazione da visualizzare Se la ricerca si estende su più pagine, è possibile visualizzare i risultati da qualsiasi pagina dei risultati. Ad esempio, per visualizzare la pagina 5 su 10, utilizzare page:5.
pageSize 10
25
50
100
La dimensione della pagina da visualizzare. La dimensione della pagina si riferisce al numero di risultati che si desidera caricare.

Se si inserisce un termine senza parametro, i risultati della ricerca vengono visualizzati per il numero del caso di supporto e per l'oggetto del caso.

Esempi di query e URL

È possibile inserire le query di ricerca nella barra di ricerca indicando un parametro e un'opzione separati da due punti (:) oppure utilizzare i parametri in un sito URL per andare direttamente a un caso specifico o a un gruppo di casi nella pagina Gestione casi.

Per utilizzare i parametri in URL, aggiungere un punto interrogativo (?) alla fine di URL. Quindi, impostare il parametro uguale all'opzione selezionata. È anche possibile separare i parametri aggiuntivi con un ampersand (&).

Per cercare un caso per parola chiave, è possibile inserire la parola nella barra di ricerca senza alcun parametro. Per cercare una parola chiave con URL, utilizzate search come parametro e impostatelo uguale alla vostra parola chiave, ad esempio search=server.

Ricerca per numero di caso

Immettere quanto segue per cercare i casi di supporto in base al numero di caso:

Query
number:CS1234567
URL
https://cloud.ibm.com/unifiedsupport/cases?number=CS1234567

Ricerca con più parametri

Potreste voler cercare sia i casi di assistenza nuovi che quelli in corso, limitare i risultati a 25 per pagina e visualizzarli per gravità. Sapete anche che il caso che state cercando non si trova nelle prime due pagine, quindi volete iniziare a pagina 5. Inserite la seguente query di ricerca:

Query
status:new,inProgress page:5 pageSize:25 sort:severity
URL
https://cloud.ibm.com/unifiedsupport/cases?status=new&status=inProgress&pageSize=25&sort=severity

Ricerca di casi risolti

Immettere la seguente query per visualizzare tutti i casi risolti in base all'ultimo aggiornamento:

Query
sort:~updatedAT status:resolved
URL
https://cloud.ibm.com/unifiedsupport/cases?sort=~updatedAT&status=resolved

Creare e gestire le etichette dei casi

È possibile creare e gestire tag personalizzati da allegare ai casi di assistenza. Questi tag aiutano a categorizzare i casi in base al servizio, all'incidente o a qualsiasi logica personalizzata, semplificando la ricerca, il filtraggio e la gestione di elevati volumi di interazioni di assistenza.

Per utilizzare i tag, l'account del cliente deve avere un livello di supporto Premium.

Creare tag nel proprio account

Prima di poter etichettare i casi, è necessario creare le etichette a livello di account. Per eseguire tale operazione, completa la procedura riportata di seguito:

  1. Andare su Assistenza > Gestisci casi.
  2. Fare clic su modifica tag per aggiungere tutti i tag necessari. Questi tag sono personalizzabili e possono riflettere servizi, incidenti, team o qualsiasi altra classificazione pertinente alla vostra organizzazione.
  3. Fare clic su Salva.

Ogni etichetta deve essere alfanumerica e non più lunga di 40 caratteri; è possibile allegare fino a 20 etichette a un singolo caso di supporto.

Gestione dei tag nel proprio account

Dopo aver creato le etichette, è possibile associarle a un caso facendo clic su Etichette caso e quindi rimuovere le etichette utilizzando la stessa interfaccia.

Per trovare casi con etichette specifiche, fare clic su una o più etichette. Ad esempio, fare clic su tag100 o tag100 e tag102 per visualizzare tutti i casi associati.

Vengono visualizzati solo i casi che contengono tutti i tag selezionati, poiché l'opzione di ricerca utilizza una condizione AND. Il filtro OR non è supportato.

Ricevere notifiche per i casi aperti utilizzando un profilo di fiducia

Quando si lavora con un profilo di fiducia e si apre un caso di assistenza, è possibile scegliere tra due opzioni per ricevere le notifiche.

Opzione 1: Le notifiche possono essere inviate al vostro indirizzo e-mail.

Opzione 2: Le notifiche possono essere inviate all'indirizzo e-mail associato al profilo di fiducia.

Per utilizzare la seconda opzione, al profilo attendibile deve essere associato un indirizzo e-mail che non sia un ID di servizio, una risorsa cloud o una risorsa informatica.